@@ -22,7 +22,7 @@ pub(crate) fn from_bstr(string: BSTR) -> String {
     unsafe {
         let len = SysStringLen(string) as usize;
 
-        let result = widestring::WideCStr::from_ptr_with_nul(string, len)
+        let result = widestring::WideStr::from_ptr(string, len)
             .to_string()
             .expect("widestring decode failed");
 
@@ -141,7 +141,7 @@ pub fn validate_dxil(data: &[u8]) -> Result<Vec<u8>, HassleError> {
     let library = dxc.create_library()?;
 
     let blob_encoding = library
-        .create_blob_with_encoding(&data)
+        .create_blob_with_encoding(data)
         .map_err(HassleError::Win32Error)?;
 
     match validator.validate(blob_encoding.into()) {
